@@ -13,7 +13,7 @@ import ujson
 import socket
 import threading
 
-from glances.compat import Fault, ProtocolError, ServerProxy
+from glances.globals import Fault, ProtocolError, ServerProxy
 from glances.client import GlancesClient, GlancesClientTransport
 from glances.logger import logger, LOG_FILENAME
 from glances.password_list import GlancesPasswordList as GlancesPassword
@@ -23,7 +23,6 @@ from glances.outputs.glances_curses_browser import GlancesCursesBrowser
 
 
 class GlancesClientBrowser(object):
-
     """This class creates and manages the TCP client browser (servers list)."""
 
     def __init__(self, config=None, args=None):
@@ -75,7 +74,7 @@ class GlancesClientBrowser(object):
                 # Try with the preconfigure password (only if status is PROTECTED)
                 clear_password = self.password.get_password(server['name'])
                 if clear_password is not None:
-                    server['password'] = self.password.sha256_hash(clear_password)
+                    server['password'] = self.password.get_hash(clear_password)
             return 'http://{}:{}@{}:{}'.format(server['username'], server['password'], server['ip'], server['port'])
         else:
             return 'http://{}:{}'.format(server['ip'], server['port'])
@@ -93,7 +92,7 @@ class GlancesClientBrowser(object):
         try:
             s = ServerProxy(uri, transport=t)
         except Exception as e:
-            logger.warning("Client browser couldn't create socket {}: {}".format(uri, e))
+            logger.warning("Client browser couldn't create socket ({})".format(e))
         else:
             # Mandatory stats
             try:
@@ -105,7 +104,7 @@ class GlancesClientBrowser(object):
                 # OS (Human Readable name)
                 server['hr_name'] = ujson.loads(s.getSystem())['hr_name']
             except (socket.error, Fault, KeyError) as e:
-                logger.debug("Error while grabbing stats form {}: {}".format(uri, e))
+                logger.debug("Error while grabbing stats form server ({})".format(e))
                 server['status'] = 'OFFLINE'
             except ProtocolError as e:
                 if e.errcode == 401:
@@ -115,7 +114,7 @@ class GlancesClientBrowser(object):
                     server['status'] = 'PROTECTED'
                 else:
                     server['status'] = 'OFFLINE'
-                logger.debug("Cannot grab stats from {} ({} {})".format(uri, e.errcode, e.errmsg))
+                logger.debug("Cannot grab stats from server ({} {})".format(e.errcode, e.errmsg))
             else:
                 # Status
                 server['status'] = 'ONLINE'
@@ -126,7 +125,7 @@ class GlancesClientBrowser(object):
                     load_min5 = ujson.loads(s.getLoad())['min5']
                     server['load_min5'] = '{:.2f}'.format(load_min5)
                 except Exception as e:
-                    logger.warning("Error while grabbing stats form {}: {}".format(uri, e))
+                    logger.warning("Error while grabbing stats form server ({})".format(e))
 
         return server
 
@@ -147,11 +146,11 @@ class GlancesClientBrowser(object):
                 # Else, the password should be enter by the user
                 # Display a popup to enter password
                 clear_password = self.screen.display_popup(
-                    'Password needed for {}: '.format(server['name']), is_input=True
+                    'Password needed for {}: '.format(server['name']), popup_type='input', is_password=True
                 )
             # Store the password for the selected server
             if clear_password is not None:
-                self.set_in_selected('password', self.password.sha256_hash(clear_password))
+                self.set_in_selected('password', self.password.get_hash(clear_password))
 
         # Display the Glance client on the selected server
         logger.info("Connect Glances client to the {} server".format(server['key']))
