@@ -15,34 +15,31 @@ import multiprocessing
 from io import open
 import re
 
-from glances.compat import ConfigParser, NoOptionError, NoSectionError, system_exec
-from glances.globals import BSD, LINUX, MACOS, SUNOS, WINDOWS
+from glances.globals import ConfigParser, NoOptionError, NoSectionError, system_exec, BSD, LINUX, MACOS, SUNOS, WINDOWS
 from glances.logger import logger
 
 
 def user_config_dir():
-    r"""Return the per-user config dir (full path).
+    r"""Return a list of per-user config dir (full path).
 
     - Linux, *BSD, SunOS: ~/.config/glances
     - macOS: ~/Library/Application Support/glances
     - Windows: %APPDATA%\glances
     """
+    paths = []
     if WINDOWS:
-        path = os.environ.get('APPDATA')
+        paths.append(os.environ.get('APPDATA'))
     elif MACOS:
-        path = os.path.expanduser('~/Library/Application Support')
+        paths.append(os.environ.get('XDG_CONFIG_HOME') or os.path.expanduser('~/.config'))
+        paths.append(os.path.expanduser('~/Library/Application Support'))
     else:
-        path = os.environ.get('XDG_CONFIG_HOME') or os.path.expanduser('~/.config')
-    if path is None:
-        path = ''
-    else:
-        path = os.path.join(path, 'glances')
+        paths.append(os.environ.get('XDG_CONFIG_HOME') or os.path.expanduser('~/.config'))
 
-    return path
+    return [os.path.join(path, 'glances') if path is not None else '' for path in paths]
 
 
 def user_cache_dir():
-    r"""Return the per-user cache dir (full path).
+    r"""Return a list of per-user cache dir (full path).
 
     - Linux, *BSD, SunOS: ~/.cache/glances
     - macOS: ~/Library/Caches/glances
@@ -55,11 +52,11 @@ def user_cache_dir():
     else:
         path = os.path.join(os.environ.get('XDG_CACHE_HOME') or os.path.expanduser('~/.cache'), 'glances')
 
-    return path
+    return [path]
 
 
 def system_config_dir():
-    r"""Return the system-wide config dir (full path).
+    r"""Return a list of system-wide config dir (full path).
 
     - Linux, SunOS: /etc/glances
     - *BSD, macOS: /usr/local/etc/glances
@@ -76,11 +73,11 @@ def system_config_dir():
     else:
         path = os.path.join(path, 'glances')
 
-    return path
+    return [path]
 
 
 def default_config_dir():
-    r"""Return the system-wide config dir (full path).
+    r"""Return a list of system-wide config dir (full path).
 
     - Linux, SunOS, *BSD, macOS: /usr/share/doc (as defined in the setup.py files)
     - Windows: %APPDATA%\glances
@@ -94,11 +91,10 @@ def default_config_dir():
     else:
         path = os.path.join(path, 'glances')
 
-    return path
+    return [path]
 
 
 class Config(object):
-
     """This class is used to access/read config file, if it exists.
 
     :param config_dir: the path to search for config file
@@ -128,7 +124,7 @@ class Config(object):
         * custom path: /path/to/glances
         * Linux, SunOS: ~/.config/glances, /etc/glances
         * *BSD: ~/.config/glances, /usr/local/etc/glances
-        * macOS: ~/Library/Application Support/glances, /usr/local/etc/glances
+        * macOS: ~/.config/glances, ~/Library/Application Support/glances, /usr/local/etc/glances
         * Windows: %APPDATA%\glances
 
         The config file will be searched in the following order of priority:
@@ -139,12 +135,18 @@ class Config(object):
         """
         paths = []
 
+        # self.config_dir is the path to the config file (via -C flag)
         if self.config_dir:
             paths.append(self.config_dir)
 
-        paths.append(os.path.join(user_config_dir(), self.config_filename))
-        paths.append(os.path.join(system_config_dir(), self.config_filename))
-        paths.append(os.path.join(default_config_dir(), self.config_filename))
+        # user_config_dir() returns a list of paths
+        paths.extend([os.path.join(path, self.config_filename) for path in user_config_dir()])
+
+        # system_config_dir() returns a list of paths
+        paths.extend([os.path.join(path, self.config_filename) for path in system_config_dir()])
+
+        # default_config_dir() returns a list of paths
+        paths.extend([os.path.join(path, self.config_filename) for path in default_config_dir()])
 
         return paths
 
@@ -322,6 +324,13 @@ class Config(object):
                 pass
         return ret
 
+    def get_list_value(self, section, option, default=None, separator=','):
+        """Get the list value of an option, if it exists."""
+        try:
+            return self.parser.get(section, option).split(separator)
+        except (NoOptionError, NoSectionError):
+            return default
+
     def get_int_value(self, section, option, default=0):
         """Get the int value of an option, if it exists."""
         try:
