@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# SPDX-FileCopyrightText: 2023 Nicolas Hennion <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2024 Nicolas Hennion <nicolas@nicolargo.com>
 #
 # SPDX-License-Identifier: LGPL-3.0-only
 #
@@ -11,11 +11,11 @@
 from __future__ import unicode_literals
 
 import sys
+import getpass
 
-from glances.compat import nativestr, u, itervalues, enable, disable
-from glances.globals import MACOS, WINDOWS
+from glances.globals import MACOS, WINDOWS, nativestr, u, itervalues, enable, disable
 from glances.logger import logger
-from glances.events import glances_events
+from glances.events_list import glances_events
 from glances.processes import glances_processes, sort_processes_key_list
 from glances.outputs.glances_unicode import unicode_message
 from glances.timer import Timer
@@ -33,22 +33,20 @@ except ImportError:
 
 
 class _GlancesCurses(object):
-
     """This class manages the curses display (and key pressed).
 
     Note: It is a private class, use GlancesCursesClient or GlancesCursesBrowser.
     """
 
     _hotkeys = {
-        # 'ENTER' > Edit the process filter
+        '\n': {'handler': '_handle_enter'},
         '0': {'switch': 'disable_irix'},
         '1': {'switch': 'percpu'},
         '2': {'switch': 'disable_left_sidebar'},
         '3': {'switch': 'disable_quicklook'},
-        # '4' > Enable or disable quicklook
-        # '5' > Enable or disable top menu
+        '4': {'handler': '_handle_quicklook'},
+        '5': {'handler': '_handle_top_menu'},
         '6': {'switch': 'meangpu'},
-        '9': {'switch': 'theme_white'},
         '/': {'switch': 'process_short_name'},
         'a': {'sort_key': 'auto'},
         'A': {'switch': 'disable_amps'},
@@ -59,8 +57,8 @@ class _GlancesCurses(object):
         'd': {'switch': 'disable_diskio'},
         'D': {'switch': 'disable_containers'},
         # 'e' > Enable/Disable process extended
-        # 'E' > Erase the process filter
-        # 'f' > Show/hide fs / folder stats
+        'E': {'handler': '_handle_erase_filter'},
+        'f': {'handler': '_handle_fs_stats'},
         'F': {'switch': 'fs_free_space'},
         'g': {'switch': 'generate_graph'},
         'G': {'switch': 'disable_gpu'},
@@ -87,12 +85,12 @@ class _GlancesCurses(object):
         'T': {'switch': 'network_sum'},
         'u': {'sort_key': 'username'},
         'U': {'switch': 'network_cumul'},
-        # 'w' > Delete finished warning logs
+        'w': {'handler': '_handle_clean_logs'},
         'W': {'switch': 'disable_wifi'},
-        # 'x' > Delete finished warning and critical logs
-        # 'z' > Enable or disable processes
-        # '+' > Increase the process nice level
-        # '-' > Decrease the process nice level
+        'x': {'handler': '_handle_clean_critical_logs'},
+        'z': {'handler': '_handle_disable_process'},
+        '+': {'handler': '_handle_increase_nice'},
+        '-': {'handler': '_handle_decrease_nice'},
         # "<" (left arrow) navigation through process sort
         # ">" (right arrow) navigation through process sort
         # 'UP' > Up in the server list
@@ -103,14 +101,17 @@ class _GlancesCurses(object):
 
     # Define top menu
     _top = ['quicklook', 'cpu', 'percpu', 'gpu', 'mem', 'memswap', 'load']
-    _quicklook_max_width = 68
+    _quicklook_max_width = 58
 
     # Define left sidebar
+    # This default list is also defined in the glances/outputs/static/js/uiconfig.json
+    # file for the web interface
+    # Both can be overwritten by the configuration file ([outputs] left_menu option)
     _left_sidebar = [
         'network',
-        'connections',
-        'wifi',
         'ports',
+        'wifi',
+        'connections',
         'diskio',
         'fs',
         'irq',
@@ -140,14 +141,21 @@ class _GlancesCurses(object):
         self.space_between_line = 2
 
         # Init the curses screen
-        self.screen = curses.initscr()
-        if not self.screen:
-            logger.critical("Cannot init the curses library.\n")
-            sys.exit(1)
-
-        # Load the 'outputs' section of the configuration file
-        # - Init the theme (default is black)
-        self.theme = {'name': 'black'}
+        try:
+            self.screen = curses.initscr()
+            if not self.screen:
+                logger.critical("Cannot init the curses library.\n")
+                sys.exit(1)
+            else:
+                logger.debug("Curses library initialized with term: {}".format(curses.longname()))
+        except Exception as e:
+            if args.export:
+                logger.info("Cannot init the curses library, quiet mode on and export.")
+                args.quiet = True
+                return
+            else:
+                logger.critical("Cannot init the curses library ({})".format(e))
+                sys.exit(1)
 
         # Load configuration file
         self.load_config(config)
@@ -187,15 +195,12 @@ class _GlancesCurses(object):
 
     def load_config(self, config):
         """Load the outputs section of the configuration file."""
-        # Load the theme
         if config is not None and config.has_section('outputs'):
             logger.debug('Read the outputs section in the configuration file')
-            self.theme['name'] = config.get_value('outputs', 'curse_theme', default='black')
-            logger.debug('Theme for the curse interface: {}'.format(self.theme['name']))
-
-    def is_theme(self, name):
-        """Return True if the theme *name* should be used."""
-        return getattr(self.args, 'theme_' + name) or self.theme['name'] == name
+            # Separator ?
+            self.args.enable_separator = config.get_bool_value('outputs', 'separator', default=True)
+            # Set the left sidebar list
+            self._left_sidebar = config.get_list_value('outputs', 'left_menu', default=self._left_sidebar)
 
     def _init_history(self):
         """Init the history option."""
@@ -237,74 +242,74 @@ class _GlancesCurses(object):
 
         if curses.has_colors():
             # The screen is compatible with a colored design
-            if self.is_theme('white'):
-                # White theme: black ==> white
-                curses.init_pair(1, curses.COLOR_BLACK, -1)
-            else:
-                curses.init_pair(1, curses.COLOR_WHITE, -1)
+            # ex: export TERM=xterm-256color
+            #     export TERM=xterm-color
+
+            curses.init_pair(1, -1, -1)
             if self.args.disable_bg:
                 curses.init_pair(2, curses.COLOR_RED, -1)
                 curses.init_pair(3, curses.COLOR_GREEN, -1)
-                curses.init_pair(4, curses.COLOR_BLUE, -1)
                 curses.init_pair(5, curses.COLOR_MAGENTA, -1)
             else:
-                curses.init_pair(2, curses.COLOR_WHITE, curses.COLOR_RED)
-                curses.init_pair(3, curses.COLOR_WHITE, curses.COLOR_GREEN)
-                curses.init_pair(4, curses.COLOR_WHITE, curses.COLOR_BLUE)
-                curses.init_pair(5, curses.COLOR_WHITE, curses.COLOR_MAGENTA)
+                curses.init_pair(2, -1, curses.COLOR_RED)
+                curses.init_pair(3, -1, curses.COLOR_GREEN)
+                curses.init_pair(5, -1, curses.COLOR_MAGENTA)
+            curses.init_pair(4, curses.COLOR_BLUE, -1)
             curses.init_pair(6, curses.COLOR_RED, -1)
             curses.init_pair(7, curses.COLOR_GREEN, -1)
-            curses.init_pair(8, curses.COLOR_BLUE, -1)
+            curses.init_pair(8, curses.COLOR_MAGENTA, -1)
 
             # Colors text styles
             self.no_color = curses.color_pair(1)
             self.default_color = curses.color_pair(3) | A_BOLD
-            self.nice_color = curses.color_pair(5)
-            self.cpu_time_color = curses.color_pair(5)
+            self.nice_color = curses.color_pair(8)
+            self.cpu_time_color = curses.color_pair(8)
             self.ifCAREFUL_color = curses.color_pair(4) | A_BOLD
             self.ifWARNING_color = curses.color_pair(5) | A_BOLD
             self.ifCRITICAL_color = curses.color_pair(2) | A_BOLD
             self.default_color2 = curses.color_pair(7)
-            self.ifCAREFUL_color2 = curses.color_pair(8) | A_BOLD
-            self.ifWARNING_color2 = curses.color_pair(5) | A_BOLD
+            self.ifCAREFUL_color2 = curses.color_pair(4)
+            self.ifWARNING_color2 = curses.color_pair(8) | A_BOLD
             self.ifCRITICAL_color2 = curses.color_pair(6) | A_BOLD
-            self.ifINFO_color = curses.color_pair(8)
+            self.ifINFO_color = curses.color_pair(4)
             self.filter_color = A_BOLD
             self.selected_color = A_BOLD
+            self.separator = curses.color_pair(1)
 
-            if curses.COLOR_PAIRS > 8:
-                colors_list = [curses.COLOR_MAGENTA, curses.COLOR_CYAN, curses.COLOR_YELLOW]
+            if curses.COLORS > 8:
+                # ex: export TERM=xterm-256color
+                colors_list = [curses.COLOR_CYAN, curses.COLOR_YELLOW]
                 for i in range(0, 3):
                     try:
                         curses.init_pair(i + 9, colors_list[i], -1)
                     except Exception:
-                        if self.is_theme('white'):
-                            curses.init_pair(i + 9, curses.COLOR_BLACK, -1)
-                        else:
-                            curses.init_pair(i + 9, curses.COLOR_WHITE, -1)
-                self.nice_color = curses.color_pair(9)
-                self.cpu_time_color = curses.color_pair(9)
-                self.ifWARNING_color2 = curses.color_pair(9) | A_BOLD
-                self.filter_color = curses.color_pair(10) | A_BOLD
-                self.selected_color = curses.color_pair(11) | A_BOLD
+                        curses.init_pair(i + 9, -1, -1)
+                self.filter_color = curses.color_pair(9) | A_BOLD
+                self.selected_color = curses.color_pair(10) | A_BOLD
+                # Define separator line style
+                curses.init_color(11, 500, 500, 500)
+                curses.init_pair(11, curses.COLOR_BLACK, -1)
+                self.separator = curses.color_pair(11)
 
         else:
             # The screen is NOT compatible with a colored design
             # switch to B&W text styles
-            self.no_color = curses.A_NORMAL
-            self.default_color = curses.A_NORMAL
+            # ex: export TERM=xterm-mono
+            self.no_color = -1
+            self.default_color = -1
             self.nice_color = A_BOLD
             self.cpu_time_color = A_BOLD
-            self.ifCAREFUL_color = curses.A_UNDERLINE
-            self.ifWARNING_color = A_BOLD
+            self.ifCAREFUL_color = A_BOLD
+            self.ifWARNING_color = curses.A_UNDERLINE
             self.ifCRITICAL_color = curses.A_REVERSE
-            self.default_color2 = curses.A_NORMAL
-            self.ifCAREFUL_color2 = curses.A_UNDERLINE
-            self.ifWARNING_color2 = A_BOLD
+            self.default_color2 = -1
+            self.ifCAREFUL_color2 = A_BOLD
+            self.ifWARNING_color2 = curses.A_UNDERLINE
             self.ifCRITICAL_color2 = curses.A_REVERSE
             self.ifINFO_color = A_BOLD
             self.filter_color = A_BOLD
             self.selected_color = A_BOLD
+            self.separator = -1
 
         # Define the colors list (hash table) for stats
         self.colors_list = {
@@ -331,6 +336,8 @@ class _GlancesCurses(object):
             'PASSWORD': curses.A_PROTECT,
             'SELECTED': self.selected_color,
             'INFO': self.ifINFO_color,
+            'ERROR': self.selected_color,
+            'SEPARATOR': self.separator,
         }
 
     def set_cursor(self, value):
@@ -347,7 +354,7 @@ class _GlancesCurses(object):
                 pass
 
     def get_key(self, window):
-        # @TODO: Check issue #163
+        # TODO: Check issue #163
         ret = window.getch()
         return ret
 
@@ -361,123 +368,135 @@ class _GlancesCurses(object):
         logger.debug("Keypressed (code: {})".format(self.pressedkey))
         for hotkey in self._hotkeys:
             if self.pressedkey == ord(hotkey) and 'switch' in self._hotkeys[hotkey]:
-                # Get the option name
-                # Ex: disable_foo return foo
-                #     enable_foo_bar return foo_bar
-                option = '_'.join(self._hotkeys[hotkey]['switch'].split('_')[1:])
-                if self._hotkeys[hotkey]['switch'].startswith('disable_'):
-                    # disable_ switch
-                    if getattr(self.args, self._hotkeys[hotkey]['switch']):
-                        enable(self.args, option)
-                    else:
-                        disable(self.args, option)
-                elif self._hotkeys[hotkey]['switch'].startswith('enable_'):
-                    # enable_ switch
-                    if getattr(self.args, self._hotkeys[hotkey]['switch']):
-                        disable(self.args, option)
-                    else:
-                        enable(self.args, option)
-                else:
-                    # Others switchs options (with no enable_ or disable_)
-                    setattr(
-                        self.args,
-                        self._hotkeys[hotkey]['switch'],
-                        not getattr(self.args, self._hotkeys[hotkey]['switch']),
-                    )
-            if self.pressedkey == ord(hotkey) and 'sort_key' in self._hotkeys[hotkey]:
-                glances_processes.set_sort_key(
-                    self._hotkeys[hotkey]['sort_key'], self._hotkeys[hotkey]['sort_key'] == 'auto'
-                )
+                self._handle_switch(hotkey)
+            elif self.pressedkey == ord(hotkey) and 'sort_key' in self._hotkeys[hotkey]:
+                self._handle_sort_key(hotkey)
+            if self.pressedkey == ord(hotkey) and 'handler' in self._hotkeys[hotkey]:
+                action = getattr(self, self._hotkeys[hotkey]['handler'])
+                action()
 
-        # Other actions...
-        if self.pressedkey == ord('\n'):
-            # 'ENTER' > Edit the process filter
-            self.edit_filter = not self.edit_filter
-        elif self.pressedkey == ord('4'):
-            # '4' > Enable or disable quicklook
-            self.args.full_quicklook = not self.args.full_quicklook
-            if self.args.full_quicklook:
-                self.enable_fullquicklook()
-            else:
-                self.disable_fullquicklook()
-        elif self.pressedkey == ord('5'):
-            # '5' > Enable or disable top menu
-            self.args.disable_top = not self.args.disable_top
-            if self.args.disable_top:
-                self.disable_top()
-            else:
-                self.enable_top()
-        elif self.pressedkey == ord('9'):
-            # '9' > Theme from black to white and reverse
-            self._init_colors()
-        elif self.pressedkey == ord('e') and not self.args.programs:
-            # 'e' > Enable/Disable process extended
-            self.args.enable_process_extended = not self.args.enable_process_extended
-            if not self.args.enable_process_extended:
-                glances_processes.disable_extended()
-            else:
-                glances_processes.enable_extended()
-            # When a process is selected (and only in standalone mode), disable the cursor
-            self.args.disable_cursor = self.args.enable_process_extended and self.args.is_standalone
-        elif self.pressedkey == ord('E'):
-            # 'E' > Erase the process filter
-            glances_processes.process_filter = None
-        elif self.pressedkey == ord('f'):
-            # 'f' > Show/hide fs / folder stats
-            self.args.disable_fs = not self.args.disable_fs
-            self.args.disable_folders = not self.args.disable_folders
-        elif self.pressedkey == ord('+'):
-            # '+' > Increase process nice level
-            self.increase_nice_process = not self.increase_nice_process
-        elif self.pressedkey == ord('-'):
-            # '+' > Decrease process nice level
-            self.decrease_nice_process = not self.decrease_nice_process
+        # Other actions with key > 255 (ord will not work) and/or additional test...
+        if self.pressedkey == ord('e') and not self.args.programs:
+            self._handle_process_extended()
         elif self.pressedkey == ord('k') and not self.args.disable_cursor:
-            # 'k' > Kill selected process (after confirmation)
-            self.kill_process = not self.kill_process
-        elif self.pressedkey == ord('w'):
-            # 'w' > Delete finished warning logs
-            glances_events.clean()
-        elif self.pressedkey == ord('x'):
-            # 'x' > Delete finished warning and critical logs
-            glances_events.clean(critical=True)
-        elif self.pressedkey == ord('z'):
-            # 'z' > Enable or disable processes
-            self.args.disable_process = not self.args.disable_process
-            if self.args.disable_process:
-                glances_processes.disable()
-            else:
-                glances_processes.enable()
+            self._handle_kill_process()
         elif self.pressedkey == curses.KEY_LEFT:
-            # "<" (left arrow) navigation through process sort
-            next_sort = (self.loop_position() - 1) % len(self._sort_loop)
-            glances_processes.set_sort_key(self._sort_loop[next_sort], False)
+            self._handle_sort_left()
         elif self.pressedkey == curses.KEY_RIGHT:
-            # ">" (right arrow) navigation through process sort
-            next_sort = (self.loop_position() + 1) % len(self._sort_loop)
-            glances_processes.set_sort_key(self._sort_loop[next_sort], False)
+            self._handle_sort_right()
         elif self.pressedkey == curses.KEY_UP or self.pressedkey == 65 and not self.args.disable_cursor:
-            # 'UP' > Up in the server list
-            if self.args.cursor_position > 0:
-                self.args.cursor_position -= 1
+            self._handle_cursor_up()
         elif self.pressedkey == curses.KEY_DOWN or self.pressedkey == 66 and not self.args.disable_cursor:
-            # 'DOWN' > Down in the server list
-            # if self.args.cursor_position < glances_processes.max_processes - 2:
-            if self.args.cursor_position < glances_processes.processes_count:
-                self.args.cursor_position += 1
+            self._handle_cursor_down()
         elif self.pressedkey == ord('\x1b') or self.pressedkey == ord('q'):
-            # 'ESC'|'q' > Quit
-            if return_to_browser:
-                logger.info("Stop Glances client and return to the browser")
-            else:
-                logger.info("Stop Glances (keypressed: {})".format(self.pressedkey))
-        elif self.pressedkey == curses.KEY_F5:
-            # "F5" manual refresh requested
-            pass
+            self._handle_quit(return_to_browser)
+        elif self.pressedkey == curses.KEY_F5 or self.pressedkey == 18:
+            self._handle_refresh()
 
         # Return the key code
         return self.pressedkey
 
+    def _handle_switch(self, hotkey):
+        option = '_'.join(self._hotkeys[hotkey]['switch'].split('_')[1:])
+        if self._hotkeys[hotkey]['switch'].startswith('disable_'):
+            if getattr(self.args, self._hotkeys[hotkey]['switch']):
+                enable(self.args, option)
+            else:
+                disable(self.args, option)
+        elif self._hotkeys[hotkey]['switch'].startswith('enable_'):
+            if getattr(self.args, self._hotkeys[hotkey]['switch']):
+                disable(self.args, option)
+            else:
+                enable(self.args, option)
+        else:
+            setattr(
+                self.args,
+                self._hotkeys[hotkey]['switch'],
+                not getattr(self.args, self._hotkeys[hotkey]['switch']),
+            )
+
+    def _handle_sort_key(self, hotkey):
+        glances_processes.set_sort_key(self._hotkeys[hotkey]['sort_key'], self._hotkeys[hotkey]['sort_key'] == 'auto')
+
+    def _handle_enter(self):
+        self.edit_filter = not self.edit_filter
+
+    def _handle_quicklook(self):
+        self.args.full_quicklook = not self.args.full_quicklook
+        if self.args.full_quicklook:
+            self.enable_fullquicklook()
+        else:
+            self.disable_fullquicklook()
+
+    def _handle_top_menu(self):
+        self.args.disable_top = not self.args.disable_top
+        if self.args.disable_top:
+            self.disable_top()
+        else:
+            self.enable_top()
+
+    def _handle_process_extended(self):
+        self.args.enable_process_extended = not self.args.enable_process_extended
+        if not self.args.enable_process_extended:
+            glances_processes.disable_extended()
+        else:
+            glances_processes.enable_extended()
+        self.args.disable_cursor = self.args.enable_process_extended and self.args.is_standalone
+
+    def _handle_erase_filter(self):
+        glances_processes.process_filter = None
+
+    def _handle_fs_stats(self):
+        self.args.disable_fs = not self.args.disable_fs
+        self.args.disable_folders = not self.args.disable_folders
+
+    def _handle_increase_nice(self):
+        self.increase_nice_process = not self.increase_nice_process
+
+    def _handle_decrease_nice(self):
+        self.decrease_nice_process = not self.decrease_nice_process
+
+    def _handle_kill_process(self):
+        self.kill_process = not self.kill_process
+
+    def _handle_clean_logs(self):
+        glances_events.clean()
+
+    def _handle_clean_critical_logs(self):
+        glances_events.clean(critical=True)
+
+    def _handle_disable_process(self):
+        self.args.disable_process = not self.args.disable_process
+        if self.args.disable_process:
+            glances_processes.disable()
+        else:
+            glances_processes.enable()
+
+    def _handle_sort_left(self):
+        next_sort = (self.loop_position() - 1) % len(self._sort_loop)
+        glances_processes.set_sort_key(self._sort_loop[next_sort], False)
+
+    def _handle_sort_right(self):
+        next_sort = (self.loop_position() + 1) % len(self._sort_loop)
+        glances_processes.set_sort_key(self._sort_loop[next_sort], False)
+
+    def _handle_cursor_up(self):
+        if self.args.cursor_position > 0:
+            self.args.cursor_position -= 1
+
+    def _handle_cursor_down(self):
+        if self.args.cursor_position < glances_processes.processes_count:
+            self.args.cursor_position += 1
+
+    def _handle_quit(self, return_to_browser):
+        if return_to_browser:
+            logger.info("Stop Glances client and return to the browser")
+        else:
+            logger.info("Stop Glances (keypressed: {})".format(self.pressedkey))
+
+    def _handle_refresh(self):
+        pass
+
     def loop_position(self):
         """Return the current sort in the loop"""
         for i, v in enumerate(self._sort_loop):
@@ -512,12 +531,14 @@ class _GlancesCurses(object):
             curses.echo()
         if hasattr(curses, 'nocbreak'):
             curses.nocbreak()
-        if hasattr(curses, 'curs_set'):
-            try:
-                curses.curs_set(1)
-            except Exception:
-                pass
-        curses.endwin()
+        try:
+            curses.curs_set(1)
+        except Exception:
+            pass
+        try:
+            curses.endwin()
+        except Exception:
+            pass
 
     def init_line_column(self):
         """Init the line and column position for the curses interface."""
@@ -542,8 +563,8 @@ class _GlancesCurses(object):
         """New column in the curses interface."""
         self.column = self.next_column
 
-    def separator_line(self, color='TITLE'):
-        """New separator line in the curses interface."""
+    def separator_line(self, color='SEPARATOR'):
+        """Add a separator line in the curses interface."""
         if not self.args.enable_separator:
             return
         self.new_line()
@@ -575,16 +596,17 @@ class _GlancesCurses(object):
         ret = {}
 
         for p in stats.getPluginsList(enable=False):
-            if p == 'quicklook' or p == 'processlist':
-                # processlist is done later
-                # because we need to know how many processes could be displayed
+            # Ignore Quicklook because it is compute later in __display_top
+            if p == 'quicklook':
                 continue
 
-            # Compute the plugin max size
+            # Compute the plugin max size for the left sidebar
             plugin_max_width = None
             if p in self._left_sidebar:
-                plugin_max_width = max(self._left_sidebar_min_width, self.term_window.getmaxyx()[1] - 105)
-                plugin_max_width = min(self._left_sidebar_max_width, plugin_max_width)
+                plugin_max_width = min(
+                    self._left_sidebar_max_width,
+                    max(self._left_sidebar_min_width, self.term_window.getmaxyx()[1] - 105),
+                )
 
             # Get the view
             ret[p] = stats.get_plugin(p).get_stats_display(args=self.args, max_width=plugin_max_width)
@@ -609,38 +631,10 @@ class _GlancesCurses(object):
         # Update the stats messages
         ###########################
 
-        # Get all the plugins but quicklook and process list
+        # Get all the plugins view
         self.args.cs_status = cs_status
         __stat_display = self.__get_stat_display(stats, layer=cs_status)
 
-        # Adapt number of processes to the available space
-        max_processes_displayed = (
-            self.term_window.getmaxyx()[0]
-            - 11
-            - (0 if 'containers' not in __stat_display else self.get_stats_display_height(__stat_display["containers"]))
-            - (
-                0
-                if 'processcount' not in __stat_display
-                else self.get_stats_display_height(__stat_display["processcount"])
-            )
-            - (0 if 'amps' not in __stat_display else self.get_stats_display_height(__stat_display["amps"]))
-            - (0 if 'alert' not in __stat_display else self.get_stats_display_height(__stat_display["alert"]))
-        )
-
-        try:
-            if self.args.enable_process_extended:
-                max_processes_displayed -= 4
-        except AttributeError:
-            pass
-        if max_processes_displayed < 0:
-            max_processes_displayed = 0
-        if glances_processes.max_processes is None or glances_processes.max_processes != max_processes_displayed:
-            logger.debug("Set number of displayed processes to {}".format(max_processes_displayed))
-            glances_processes.max_processes = max_processes_displayed
-
-        # Get the processlist
-        __stat_display["processlist"] = stats.get_plugin('processlist').get_stats_display(args=self.args)
-
         # Display the stats on the curses interface
         ###########################################
 
@@ -651,10 +645,10 @@ class _GlancesCurses(object):
             # ... and exit
             return False
 
-        # =====================================
+        # =======================================
         # Display first line (system+ip+uptime)
-        # Optionally: Cloud on second line
-        # =====================================
+        # Optionally: Cloud is on the second line
+        # =======================================
         self.__display_header(__stat_display)
         self.separator_line()
 
@@ -889,7 +883,13 @@ class _GlancesCurses(object):
         for p in self._left_sidebar:
             if (hasattr(self.args, 'enable_' + p) or hasattr(self.args, 'disable_' + p)) and p in stat_display:
                 self.new_line()
-                self.display_plugin(stat_display[p])
+                if p == 'sensors':
+                    self.display_plugin(
+                        stat_display['sensors'],
+                        max_y=(self.term_window.getmaxyx()[0] - self.get_stats_display_height(stat_display['now']) - 2),
+                    )
+                else:
+                    self.display_plugin(stat_display[p])
 
     def __display_right(self, stat_display):
         """Display the right sidebar in the Curses interface.
@@ -907,9 +907,6 @@ class _GlancesCurses(object):
         self.new_column()
         for p in self._right_sidebar:
             if (hasattr(self.args, 'enable_' + p) or hasattr(self.args, 'disable_' + p)) and p in stat_display:
-                if p not in p:
-                    # Catch for issue #1470
-                    continue
                 self.new_line()
                 if p == 'processlist':
                     self.display_plugin(
@@ -924,12 +921,20 @@ class _GlancesCurses(object):
                     self.display_plugin(stat_display[p])
 
     def display_popup(
-        self, message, size_x=None, size_y=None, duration=3, popup_type='info', input_size=30, input_value=None
+        self,
+        message,
+        size_x=None,
+        size_y=None,
+        duration=3,
+        popup_type='info',
+        input_size=30,
+        input_value=None,
+        is_password=False,
     ):
         """
         Display a centered popup.
 
-         popup_type: ='info'
+        popup_type: ='info'
          Just an information popup, no user interaction
          Display a centered popup with the given message during duration seconds
          If size_x and size_y: set the popup size
@@ -973,7 +978,8 @@ class _GlancesCurses(object):
 
         # Add the message
         for y, m in enumerate(sentence_list):
-            popup.addnstr(2 + y, 2, m, len(m))
+            if len(m) > 0:
+                popup.addnstr(2 + y, 2, m, len(m))
 
         if popup_type == 'info':
             # Display the popup
@@ -981,6 +987,8 @@ class _GlancesCurses(object):
             self.wait(duration * 1000)
             return True
         elif popup_type == 'input':
+            logger.info(popup_type)
+            logger.info(is_password)
             # Create a sub-window for the text field
             sub_pop = popup.derwin(1, input_size, 2, 2 + len(m))
             sub_pop.attron(self.colors_list['FILTER'])
@@ -993,16 +1001,21 @@ class _GlancesCurses(object):
             # Create the textbox inside the sub-windows
             self.set_cursor(2)
             self.term_window.keypad(1)
-            textbox = GlancesTextbox(sub_pop, insert_mode=True)
-            textbox.edit()
-            self.set_cursor(0)
-            # self.term_window.keypad(0)
-            if textbox.gather() != '':
-                logger.debug("User enters the following string: %s" % textbox.gather())
-                return textbox.gather()[:-1]
+            if is_password:
+                textbox = getpass.getpass('')
+                self.set_cursor(0)
+                if textbox != '':
+                    return textbox
+                else:
+                    return None
             else:
-                logger.debug("User centers an empty string")
-                return None
+                textbox = GlancesTextbox(sub_pop, insert_mode=True)
+                textbox.edit()
+                self.set_cursor(0)
+                if textbox.gather() != '':
+                    return textbox.gather()[:-1]
+                else:
+                    return None
         elif popup_type == 'yesno':
             # # Create a sub-window for the text field
             sub_pop = popup.derwin(1, 2, len(sentence_list) + 1, len(m) + 2)
@@ -1116,12 +1129,28 @@ class _GlancesCurses(object):
         # Have empty lines after the plugins
         self.next_line += add_space
 
-    def erase(self):
-        """Erase the content of the screen."""
+    def clear(self):
+        """Erase the content of the screen.
+        The difference is that clear() also calls clearok(). clearok()
+        basically tells ncurses to forget whatever it knows about the current
+        terminal contents, so that when refresh() is called, it will actually
+        begin by clearing the entire terminal screen before redrawing any of it."""
         self.term_window.clear()
 
+    def erase(self):
+        """Erase the content of the screen.
+        erase() on the other hand, just clears the screen (the internal
+        object, not the terminal screen). When refresh() is later called,
+        ncurses will still compute the minimum number of characters to send to
+        update the terminal."""
+        self.term_window.erase()
+
+    def refresh(self):
+        """Refresh the windows"""
+        self.term_window.refresh()
+
     def flush(self, stats, cs_status=None):
-        """Clear and update the screen.
+        """Erase and update the screen.
 
         :param stats: Stats database to display
         :param cs_status:
@@ -1129,8 +1158,10 @@ class _GlancesCurses(object):
             "Connected": Client is connected to the server
             "Disconnected": Client is disconnected from the server
         """
+        # See https://stackoverflow.com/a/43486979/1919431
         self.erase()
         self.display(stats, cs_status=cs_status)
+        self.refresh()
 
     def update(self, stats, duration=3, cs_status=None, return_to_browser=False):
         """Update the screen.
@@ -1166,8 +1197,9 @@ class _GlancesCurses(object):
             pressedkey = self.__catch_key(return_to_browser=return_to_browser)
             isexitkey = pressedkey == ord('\x1b') or pressedkey == ord('q')
 
-            if pressedkey == curses.KEY_F5:
-                # Were asked to refresh
+            if pressedkey == curses.KEY_F5 or self.pressedkey == 18:
+                # Were asked to refresh (F5 or Ctrl-R)
+                self.clear()
                 return isexitkey
 
             if pressedkey in (curses.KEY_UP, 65, curses.KEY_DOWN, 66):
@@ -1191,7 +1223,7 @@ class _GlancesCurses(object):
 
     def wait(self, delay=100):
         """Wait delay in ms"""
-        curses.napms(100)
+        curses.napms(delay)
 
     def get_stats_display_width(self, curse_msg, without_option=False):
         """Return the width of the formatted curses message."""
@@ -1240,12 +1272,10 @@ class _GlancesCurses(object):
 
 
 class GlancesCursesStandalone(_GlancesCurses):
-
     """Class for the Glances curse standalone."""
 
 
 class GlancesCursesClient(_GlancesCurses):
-
     """Class for the Glances curse client."""
 
 
