@@ -2,34 +2,20 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """StdoutCsv interface class."""
 
 import time
 
-from glances.logger import logger
-from glances.compat import printandflush
+from glances.globals import printandflush
 
 
 class GlancesStdoutCsv(object):
-
-    """
-    This class manages the StdoutCsv display.
-    """
+    """This class manages the StdoutCsv display."""
 
     separator = ','
     na = 'N/A'
@@ -47,7 +33,9 @@ class GlancesStdoutCsv(object):
 
     def build_list(self):
         """Return a list of tuples taken from self.args.stdout
-        [(plugin, attribute), ... ]"""
+
+        :return: A list of tuples. Example -[(plugin, attribute), ... ]
+        """
         ret = []
         for p in self.args.stdout_csv.split(','):
             if '.' in p:
@@ -69,17 +57,12 @@ class GlancesStdoutCsv(object):
         else:
             if isinstance(stat, dict):
                 for k in stat.keys():
-                    line += '{}.{}{}'.format(plugin,
-                                             str(k),
-                                             self.separator)
+                    line += '{}.{}{}'.format(plugin, str(k), self.separator)
             elif isinstance(stat, list):
                 for i in stat:
                     if isinstance(i, dict) and 'key' in i:
                         for k in i.keys():
-                            line += '{}.{}.{}{}'.format(plugin,
-                                                        str(i[i['key']]),
-                                                        str(k),
-                                                        self.separator)
+                            line += '{}.{}.{}{}'.format(plugin, str(i[i['key']]), str(k), self.separator)
             else:
                 line += '{}{}'.format(plugin, self.separator)
 
@@ -90,8 +73,7 @@ class GlancesStdoutCsv(object):
         line = ''
 
         if attribute is not None:
-            line += '{}{}'.format(str(stat.get(attribute, self.na)),
-                                  self.separator)
+            line += '{}{}'.format(str(stat.get(attribute, self.na)), self.separator)
         else:
             if isinstance(stat, dict):
                 for v in stat.values():
@@ -106,18 +88,16 @@ class GlancesStdoutCsv(object):
 
         return line
 
-    def update(self,
-               stats,
-               duration=3):
+    def update(self, stats, duration=3):
         """Display stats to stdout.
+
         Refresh every duration second.
         """
         # Build the stats list
         line = ''
         for plugin, attribute in self.plugins_list:
             # Check if the plugin exist and is enable
-            if plugin in stats.getPluginsList() and \
-               stats.get_plugin(plugin).is_enabled():
+            if plugin in stats.getPluginsList() and stats.get_plugin(plugin).is_enabled():
                 stat = stats.get_plugin(plugin).get_export()
             else:
                 continue
