@@ -2,22 +2,24 @@
 #
 # This file is part of Glances.
 #
-# SPDX-FileCopyrightText: 2023 Nicolas Hennion <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2024 Nicolas Hennion <nicolas@nicolargo.com>
 #
 # SPDX-License-Identifier: LGPL-3.0-only
 #
 
 import os
 
-from glances.compat import iterkeys
-from glances.globals import BSD, LINUX, MACOS, WINDOWS
+from glances.globals import BSD, LINUX, MACOS, WINDOWS, iterkeys
+from glances.globals import namedtuple_to_dict, list_of_namedtuple_to_list_of_dict
 from glances.timer import Timer, getTimeSinceLastUpdate
-from glances.filter import GlancesFilter
+from glances.filter import GlancesFilterList, GlancesFilter
 from glances.programs import processes_to_programs
 from glances.logger import logger
 
 import psutil
 
+psutil_version_info = tuple([int(num) for num in psutil.__version__.split('.')])
+
 # This constant defines the list of available processes sort key
 sort_processes_key_list = ['cpu_percent', 'memory_percent', 'username', 'cpu_times', 'io_counters', 'name']
 
@@ -42,11 +44,6 @@ class GlancesProcesses(object):
         # Should be set by the set_args method
         self.args = None
 
-        # Add internals caches because psutil do not cache all the stats
-        # See: https://github.com/giampaolo/psutil/issues/462
-        self.username_cache = {}
-        self.cmdline_cache = {}
-
         # The internals caches will be cleaned each 'cache_timeout' seconds
         self.cache_timeout = cache_timeout
         # First iteration, no cache
@@ -69,6 +66,11 @@ class GlancesProcesses(object):
         # Cache is a dict with key=pid and value = dict of cached value
         self.processlist_cache = {}
 
+        # List of processes stats to export
+        # Only process matching one of the filter will be exported
+        self._filter_export = GlancesFilterList()
+        self.processlist_export = []
+
         # Tag to enable/disable the processes stats (to reduce the Glances CPU consumption)
         # Default is to enable the processes stats
         self.disable_tag = False
@@ -102,7 +104,7 @@ class GlancesProcesses(object):
         # Maximum number of processes showed in the UI (None if no limit)
         self._max_processes = None
 
-        # Process filter is a regular expression
+        # Process filter
         self._filter = GlancesFilter()
 
         # Whether or not to hide kernel threads
@@ -202,6 +204,8 @@ class GlancesProcesses(object):
         """Set the maximum number of processes showed in the UI."""
         self._max_processes = value
 
+    # Process filter
+
     @property
     def process_filter_input(self):
         """Get the process filter (given by the user)."""
@@ -227,6 +231,20 @@ class GlancesProcesses(object):
         """Get the process regular expression compiled."""
         return self._filter.filter_re
 
+    # Export filter
+
+    @property
+    def export_process_filter(self):
+        """Get the export process filter (current export process filter list)."""
+        return self._filter_export.filter
+
+    @export_process_filter.setter
+    def export_process_filter(self, value):
+        """Set the export process filter list."""
+        self._filter_export.filter = value
+
+    # Kernel threads
+
     def disable_kernel_threads(self):
         """Ignore kernel threads in process list."""
         self.no_kernel_threads = True
@@ -279,66 +297,92 @@ class GlancesProcesses(object):
 
         ret = {}
         try:
-            # Get the extended stats
+            logger.debug('Grab extended stats for process {}'.format(proc['pid']))
+
+            # Get PID of the selected process
             selected_process = psutil.Process(proc['pid'])
+
+            # Get the extended stats for the selected process
             ret = selected_process.as_dict(attrs=extended_stats, ad_value=None)
 
-            if LINUX:
-                try:
-                    ret['memory_swap'] = sum([v.swap for v in selected_process.memory_maps()])
-                except (psutil.NoSuchProcess, KeyError):
-                    # (KeyError catch for issue #1551)
-                    pass
-                except (psutil.AccessDenied, NotImplementedError):
-                    # NotImplementedError: /proc/${PID}/smaps file doesn't exist
-                    # on kernel < 2.6.14 or CONFIG_MMU kernel configuration option
-                    # is not enabled (see psutil #533/glances #413).
-                    ret['memory_swap'] = None
-            try:
-                ret['tcp'] = len(selected_process.connections(kind="tcp"))
-                ret['udp'] = len(selected_process.connections(kind="udp"))
-            except (psutil.AccessDenied, psutil.NoSuchProcess):
-                # Manage issue1283 (psutil.AccessDenied)
-                ret['tcp'] = None
-                ret['udp'] = None
+            # Get memory swap for the selected process (Linux Only)
+            ret['memory_swap'] = self.__get_extended_memory_swap(selected_process)
+
+            # Get number of TCP and UDP network connections for the selected process
+            ret['tcp'], ret['udp'] = self.__get_extended_connections(selected_process)
         except (psutil.NoSuchProcess, ValueError, AttributeError) as e:
             logger.error('Can not grab extended stats ({})'.format(e))
             self.extended_process = None
             ret['extended_stats'] = False
         else:
-            logger.debug('Grab extended stats for process {}'.format(proc['pid']))
-
             # Compute CPU and MEM min/max/mean
-            for stat_prefix in ['cpu', 'memory']:
-                if stat_prefix + '_min' not in self.extended_process:
-                    ret[stat_prefix + '_min'] = proc[stat_prefix + '_percent']
-                else:
-                    ret[stat_prefix + '_min'] = (
-                        proc[stat_prefix + '_percent']
-                        if proc[stat_prefix + '_min'] > proc[stat_prefix + '_percent']
-                        else proc[stat_prefix + '_min']
-                    )
-                if stat_prefix + '_max' not in self.extended_process:
-                    ret[stat_prefix + '_max'] = proc[stat_prefix + '_percent']
-                else:
-                    ret[stat_prefix + '_max'] = (
-                        proc[stat_prefix + '_percent']
-                        if proc[stat_prefix + '_max'] < proc[stat_prefix + '_percent']
-                        else proc[stat_prefix + '_max']
-                    )
-                if stat_prefix + '_mean_sum' not in self.extended_process:
-                    ret[stat_prefix + '_mean_sum'] = proc[stat_prefix + '_percent']
-                else:
-                    ret[stat_prefix + '_mean_sum'] = proc[stat_prefix + '_mean_sum'] + proc[stat_prefix + '_percent']
-                if stat_prefix + '_mean_counter' not in self.extended_process:
-                    ret[stat_prefix + '_mean_counter'] = 1
-                else:
-                    ret[stat_prefix + '_mean_counter'] = proc[stat_prefix + '_mean_counter'] + 1
-                ret[stat_prefix + '_mean'] = ret[stat_prefix + '_mean_sum'] / ret[stat_prefix + '_mean_counter']
-
+            # Merge the returned dict with the current on
+            ret.update(self.__get_min_max_mean(proc))
+            self.extended_process = ret
             ret['extended_stats'] = True
+        return namedtuple_to_dict(ret)
+
+    def __get_min_max_mean(self, proc, prefix=['cpu', 'memory']):
+        """Return the min/max/mean for the given process"""
+        ret = {}
+        for stat_prefix in prefix:
+            min_key = stat_prefix + '_min'
+            max_key = stat_prefix + '_max'
+            mean_sum_key = stat_prefix + '_mean_sum'
+            mean_counter_key = stat_prefix + '_mean_counter'
+            if min_key not in self.extended_process:
+                ret[min_key] = proc[stat_prefix + '_percent']
+            else:
+                ret[min_key] = min(proc[stat_prefix + '_percent'], self.extended_process[min_key])
+            if max_key not in self.extended_process:
+                ret[max_key] = proc[stat_prefix + '_percent']
+            else:
+                ret[max_key] = max(proc[stat_prefix + '_percent'], self.extended_process[max_key])
+            if mean_sum_key not in self.extended_process:
+                ret[mean_sum_key] = proc[stat_prefix + '_percent']
+            else:
+                ret[mean_sum_key] = self.extended_process[mean_sum_key] + proc[stat_prefix + '_percent']
+            if mean_counter_key not in self.extended_process:
+                ret[mean_counter_key] = 1
+            else:
+                ret[mean_counter_key] = self.extended_process[mean_counter_key] + 1
+            ret[stat_prefix + '_mean'] = ret[mean_sum_key] / ret[mean_counter_key]
         return ret
 
+    def __get_extended_memory_swap(self, process):
+        """Return the memory swap for the given process"""
+        if not LINUX:
+            return None
+        try:
+            memory_swap = sum([v.swap for v in process.memory_maps()])
+        except (psutil.NoSuchProcess, KeyError):
+            # (KeyError catch for issue #1551)
+            pass
+        except (psutil.AccessDenied, NotImplementedError):
+            # NotImplementedError: /proc/${PID}/smaps file doesn't exist
+            # on kernel < 2.6.14 or CONFIG_MMU kernel configuration option
+            # is not enabled (see psutil #533/glances #413).
+            memory_swap = None
+        return memory_swap
+
+    def __get_extended_connections(self, process):
+        """Return a tuple with (tcp, udp) connections count
+        The code is compliant with both PsUtil<6 and Psutil>=6
+        """
+        try:
+            # Hack for issue #2754 (PsUtil 6+)
+            if psutil_version_info[0] >= 6:
+                tcp = len(process.net_connections(kind="tcp"))
+                udp = len(process.net_connections(kind="udp"))
+            else:
+                tcp = len(process.connections(kind="tcp"))
+                udp = len(process.connections(kind="udp"))
+        except (psutil.AccessDenied, psutil.NoSuchProcess):
+            # Manage issue1283 (psutil.AccessDenied)
+            tcp = None
+            udp = None
+        return tcp, udp
+
     def is_selected_extended_process(self, position):
         """Return True if the process is the selected one for extended stats."""
         return (
@@ -354,13 +398,12 @@ class GlancesProcesses(object):
 
     def update(self):
         """Update the processes stats."""
-        # Reset the stats
-        self.processlist = []
-        self.reset_processcount()
+        # Init new processes stats
+        processlist = []
 
         # Do not process if disable tag is set
         if self.disable_tag:
-            return
+            return processlist
 
         # Time since last update (for disk_io rate computation)
         time_since_update = getTimeSinceLastUpdate('process_disk')
@@ -369,7 +412,8 @@ class GlancesProcesses(object):
         #####################
         sorted_attrs = ['cpu_percent', 'cpu_times', 'memory_percent', 'name', 'status', 'num_threads']
         displayed_attr = ['memory_info', 'nice', 'pid']
-        # 'name' can not be cached because it is used for filtering
+        # The following attributes are cached and only retreive every self.cache_timeout seconds
+        # Warning: 'name' can not be cached because it is used for filtering
         cached_attrs = ['cmdline', 'username']
 
         # Some stats are optional
@@ -392,8 +436,8 @@ class GlancesProcesses(object):
 
         # Build the processes stats list (it is why we need psutil>=5.3.0)
         # This is one of the main bottleneck of Glances (see flame graph)
-        # Filter processes
-        self.processlist = list(
+        # It may be optimized with PsUtil 6+ (see issue #2755)
+        processlist = list(
             filter(
                 lambda p: not (BSD and p.info['name'] == 'idle')
                 and not (WINDOWS and p.info['name'] == 'System Idle Process')
@@ -403,17 +447,17 @@ class GlancesProcesses(object):
             )
         )
         # Only get the info key
-        self.processlist = [p.info for p in self.processlist]
+        processlist = [p.info for p in processlist]
         # Sort the processes list by the current sort_key
-        self.processlist = sort_stats(self.processlist, sorted_by=self.sort_key, reverse=True)
+        processlist = sort_stats(processlist, sorted_by=self.sort_key, reverse=True)
 
         # Update the processcount
-        self.update_processcount(self.processlist)
+        self.update_processcount(processlist)
 
         # Loop over processes and :
         # - add extended stats for selected process
         # - add metadata
-        for position, proc in enumerate(self.processlist):
+        for position, proc in enumerate(processlist):
             # Extended stats
             ################
 
@@ -424,7 +468,7 @@ class GlancesProcesses(object):
             # Grab extended stats only for the selected process (see issue #2225)
             if self.extended_process is not None and proc['pid'] == self.extended_process['pid']:
                 proc.update(self.get_extended_stats(self.extended_process))
-                self.extended_process = proc
+                self.extended_process = namedtuple_to_dict(proc)
 
             # Meta data
             ###########
@@ -444,7 +488,7 @@ class GlancesProcesses(object):
             # If io_tag = 0 > Access denied or first time (display "?")
             # If io_tag = 1 > No access denied (display the IO rate)
             if 'io_counters' in proc and proc['io_counters'] is not None:
-                io_new = [proc['io_counters'].read_bytes, proc['io_counters'].write_bytes]
+                io_new = [proc['io_counters'][2], proc['io_counters'][3]]
                 # For IO rate computation
                 # Append saved IO r/w bytes
                 try:
@@ -478,23 +522,48 @@ class GlancesProcesses(object):
                     pass
             else:
                 # Save values to cache
-                self.processlist_cache[proc['pid']] = {cached: proc[cached] for cached in cached_attrs}
+                try:
+                    self.processlist_cache[proc['pid']] = {cached: proc[cached] for cached in cached_attrs}
+                except KeyError:
+                    pass
 
-        # Apply user filter
-        self.processlist = list(filter(lambda p: not self._filter.is_filtered(p), self.processlist))
+        # Filter and transform process export list
+        self.processlist_export = self.update_export_list(processlist)
+
+        # Filter and transform process list
+        processlist = self.update_list(processlist)
 
         # Compute the maximum value for keys in self._max_values_list: CPU, MEM
         # Useful to highlight the processes with maximum values
         for k in self._max_values_list:
-            values_list = [i[k] for i in self.processlist if i[k] is not None]
+            values_list = [i[k] for i in processlist if i[k] is not None]
             if values_list:
                 self.set_max_values(k, max(values_list))
 
+        # Update the stats
+        self.processlist = processlist
+
+        return self.processlist
+
+    def update_list(self, processlist):
+        """Return the process list after filtering and transformation (namedtuple to dict)."""
+        if self._filter.filter is None:
+            return list_of_namedtuple_to_list_of_dict(processlist)
+        ret = list(filter(lambda p: self._filter.is_filtered(p), processlist))
+        return list_of_namedtuple_to_list_of_dict(ret)
+
+    def update_export_list(self, processlist):
+        """Return the process export list after filtering and transformation (namedtuple to dict)."""
+        if self._filter_export.filter == []:
+            return []
+        ret = list(filter(lambda p: self._filter_export.is_filtered(p), processlist))
+        return list_of_namedtuple_to_list_of_dict(ret)
+
     def get_count(self):
         """Get the number of processes."""
         return self.processcount
 
-    def getlist(self, sorted_by=None, as_programs=False):
+    def get_list(self, sorted_by=None, as_programs=False):
         """Get the processlist.
         By default, return the list of threads.
         If as_programs is True, return the list of programs."""
@@ -503,6 +572,10 @@ class GlancesProcesses(object):
         else:
             return self.processlist
 
+    def get_export(self):
+        """Return the processlist for export."""
+        return self.processlist_export
+
     @property
     def sort_key(self):
         """Get the current sort key."""
@@ -588,6 +661,7 @@ def _sort_lambda(sorted_by='cpu_percent', sorted_by_secondary='memory_percent'):
 
 def sort_stats(stats, sorted_by='cpu_percent', sorted_by_secondary='memory_percent', reverse=True):
     """Return the stats (dict) sorted by (sorted_by).
+    A secondary sort key should be specified.
 
     Reverse the sort if reverse is True.
     """
