@@ -9,10 +9,11 @@
 
 """Secures functions for Glances"""
 
-from glances.compat import nativestr
 from subprocess import Popen, PIPE
 import re
 
+from glances.globals import nativestr
+
 
 def secure_popen(cmd):
     """A more or less secure way to execute system commands
@@ -56,6 +57,8 @@ def __secure_popen(cmd):
         if p_last is not None:
             # Allow p_last to receive a SIGPIPE if p exits.
             p_last.stdout.close()
+            p_last.kill()
+            p_last.wait()
         p_last = p
         sub_cmd_stdin = p.stdout
 
