@@ -15,7 +15,7 @@ import sys
 from base64 import b64decode
 
 from glances import __version__
-from glances.compat import SimpleXMLRPCRequestHandler, SimpleXMLRPCServer
+from glances.globals import SimpleXMLRPCRequestHandler, SimpleXMLRPCServer
 from glances.autodiscover import GlancesAutoDiscoverClient
 from glances.logger import logger
 from glances.stats_server import GlancesStatsServer
@@ -23,7 +23,6 @@ from glances.timer import Timer
 
 
 class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
-
     """Main XML-RPC handler."""
 
     rpc_paths = ('/RPC2',)
@@ -67,7 +66,8 @@ class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
         if username in self.server.user_dict:
             from glances.password import GlancesPassword
 
-            pwd = GlancesPassword(username=username, config=self.config)
+            # TODO: config is not taken into account: it may be a problem ?
+            pwd = GlancesPassword(username=username, config=None)
             return pwd.check_password(self.server.user_dict[username], password)
         else:
             return False
@@ -88,13 +88,11 @@ class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
 
 
 class GlancesXMLRPCServer(SimpleXMLRPCServer, object):
-
     """Init a SimpleXMLRPCServer instance (IPv6-ready)."""
 
     finished = False
 
     def __init__(self, bind_address, bind_port=61209, requestHandler=GlancesXMLRPCHandler, config=None):
-
         self.bind_address = bind_address
         self.bind_port = bind_port
         self.config = config
@@ -118,7 +116,6 @@ class GlancesXMLRPCServer(SimpleXMLRPCServer, object):
 
 
 class GlancesInstance(object):
-
     """All the methods of this class are published as XML-RPC methods."""
 
     def __init__(self, config=None, args=None):
@@ -183,7 +180,6 @@ class GlancesInstance(object):
 
 
 class GlancesServer(object):
-
     """This class creates and manages the TCP server."""
 
     def __init__(self, requestHandler=GlancesXMLRPCHandler, config=None, args=None):
